@@ -2,15 +2,14 @@
 #
 #   DBD::CSV - A DBI driver for CSV and similar structured files
 #
-#   This module is Copyright (C) 1998 by
+#   This module is currently maintained by
 #
-#       Jochen Wiedmann
-#       Am Eisteich 9
-#       72555 Metzingen
-#       Germany
+#       Jeff Zucker
+#       <jeff@vpservices.com>
 #
-#       Email: joe@ispsoft.de
-#       Phone: +49 7123 14887
+#   The original author is Jochen Wiedmann.
+#
+#   Copyright (C) 1998 by Jochen Wiedmann
 #
 #   All rights reserved.
 #
@@ -34,7 +33,7 @@ use vars qw(@ISA $VERSION $drh $err $errstr $sqlstate);
 
 @ISA = qw(DBD::File);
 
-$VERSION = '0.1029';
+$VERSION = '0.2001';
 
 $err = 0;		# holds error code   for DBI::err
 $errstr = "";		# holds error string for DBI::errstr
@@ -333,6 +332,14 @@ Note that you almost definitely need root or administrator permissions.
 If you don't have them, read the ExtUtils::MakeMaker man page for details
 on installing in your own directories. L<ExtUtils::MakeMaker>.
 
+=head2
+
+  The level of SQL support available depends on the version of
+  SQL::Statement installed.  Any version will support *basic*
+  CREATE, INSERT, DELETE, UPDATE, and SELECT statements.  Only
+  versions of SQL::Statement 1.0 and above support additional
+  features such as table joins, string functions, etc.  See the
+  documentation of the latest version of SQL::Statement for details.
 
 =head2 Creating a database handle
 
@@ -349,6 +356,12 @@ are equivalent:
     $dbh = DBI->connect("DBI:CSV:");
     $dbh = DBI->connect("DBI:CSV:f_dir=.");
 
+(I was told, that VMS requires
+
+    $dbh = DBI->connect("DBI:CSV:f_dir=");
+
+for whatever reasons.)
+
 You may set other attributes in the DSN string, separated by semicolons.
 
 
@@ -751,12 +764,6 @@ modules:
 
 =over 4
 
-=item Joins
-
-The current version of the module works with single table SELECTs
-only, although the basic design of the SQL::Statement module allows
-joins and the like.
-
 =item Table name mapping
 
 Currently it is not possible to use files with names like C<names.csv>.
@@ -791,15 +798,14 @@ operating systems, as they are for single users anyways).
 
 =head1 AUTHOR AND COPYRIGHT
 
-This module is Copyright (C) 1998 by
+This module is currently maintained by
 
-    Jochen Wiedmann
-    Am Eisteich 9
-    72555 Metzingen
-    Germany
+      Jeff Zucker
+      <jeff@vpservices.com>
 
-    Email: joe@ispsoft.de
-    Phone: +49 7123 14887
+The original author is Jochen Wiedmann.
+
+Copyright (C) 1998 by Jochen Wiedmann
 
 All rights reserved.
 
@@ -807,7 +813,6 @@ You may distribute this module under the terms of either the GNU
 General Public License or the Artistic License, as specified in
 the Perl README file.
 
-
 =head1 SEE ALSO
 
 L<DBI(3)>, L<Text::CSV_XS(3)>, L<SQL::Statement(3)>
